@@ -14,8 +14,6 @@ class ArrayPosition(Func):
 
     def as_sql(self, compiler, connection, **extra_context):
         extra_context['index'] = compiler.compile(self._index)
-        print('-------sdfsdf-------')
-        print(extra_context['index'])
         return super().as_sql(compiler, connection, **extra_context)
 
     def as_postgresql(self, compiler, connection):
