@@ -3,6 +3,7 @@ from django.contrib.postgres.fields import ArrayField
 from django.contrib.postgres.indexes import GistIndex
 from django.utils.translation import pgettext_lazy
 
+from pxd_postgres.ltree import LtreeIntField
 from pxd_tree.adjacency_list import Tree as BaseTree
 
 
@@ -14,7 +15,7 @@ def tree_indexes(name: str = '%(app_label)s_%(class)s'):
         GistIndex(
             name=name + '_path_index',
             fields=['path'],
-            opclasses=('gist__int_ops',)
+            opclasses=('gist_ltree_ops(siglen=100)',)
         )
     ]
 
@@ -24,8 +25,7 @@ class Tree(BaseTree):
         abstract = True
         indexes = tree_indexes()
 
-    path = ArrayField(
-        models.BigIntegerField(),
+    path = LtreeIntField(
         verbose_name=pgettext_lazy('pxd_tree', 'Hierarchy path'),
-        null=False, blank=False, default=list, editable=False
+        null=False, blank=True, default='', editable=False
     )
